@@ -30,6 +30,7 @@
 #include "docparser.h"
 #include "definitionimpl.h"
 #include "filedef.h"
+#include "trace.h"
 
 
 //----------------------------------------------------------------------
@@ -47,12 +48,12 @@ class DirDefImpl : public DefinitionMixin<DirDef>
     virtual bool isLinkableInProject() const;
     virtual bool isLinkable() const;
     virtual QCString displayName(bool=TRUE) const { return m_dispName; }
-    virtual const QCString &shortName() const { return m_shortName; }
+    virtual const QCString shortName() const { return m_shortName; }
     virtual void addSubDir(DirDef *subdir);
     virtual const FileList &getFiles() const { return m_fileList; }
     virtual void addFile(const FileDef *fd);
     virtual const DirList &subDirs() const { return m_subdirs; }
-    virtual bool isCluster() const { return m_subdirs.size()>0; }
+    virtual bool hasSubdirs() const { return !m_subdirs.empty(); }
     virtual int level() const { return m_level; }
     virtual DirDef *parent() const { return m_parent; }
     virtual int dirCount() const { return m_dirCount; }
@@ -66,9 +67,10 @@ class DirDefImpl : public DefinitionMixin<DirDef>
     virtual void setDiskName(const QCString &name) { m_diskName = name; }
     virtual void sort();
     virtual void setParent(DirDef *parent);
+    virtual void setDirCount(int count);
     virtual void setLevel();
     virtual void addUsesDependency(const DirDef *usedDir,const FileDef *srcFd,
-                                   const FileDef *dstFd,bool inherited);
+                                   const FileDef *dstFd,bool srcDirect, bool dstDirect);
     virtual void computeDependencies();
 
   public:
@@ -92,7 +94,7 @@ class DirDefImpl : public DefinitionMixin<DirDef>
     QCString m_shortName;
     QCString m_diskName;
     FileList m_fileList;                 // list of files in the group
-    int m_dirCount;
+    int m_dirCount = -1;
     int m_level;
     DirDef *m_parent;
     UsedDirLinkedMap m_usedDirs;
@@ -107,8 +109,6 @@ DirDef *createDirDef(const QCString &path)
 //----------------------------------------------------------------------
 // method implementation
 
-static int g_dirCount=0;
-
 DirDefImpl::DirDefImpl(const QCString &path) : DefinitionMixin(path,1,1,path)
 {
   bool fullPathNames = Config_getBool(FULL_PATH_NAMES);
@@ -132,7 +132,6 @@ DirDefImpl::DirDefImpl(const QCString &path) : DefinitionMixin(path,1,1,path)
     m_dispName = m_dispName.left(m_dispName.length()-1);
   }
 
-  m_dirCount   = g_dirCount++;
   m_level=-1;
   m_parent=0;
 }
@@ -163,6 +162,11 @@ void DirDefImpl::setParent(DirDef *p)
    m_parent=p;
 }
 
+void DirDefImpl::setDirCount(int count)
+{
+  m_dirCount=count;
+}
+
 void DirDefImpl::addFile(const FileDef *fd)
 {
   m_fileList.push_back(fd);
@@ -177,11 +181,13 @@ void DirDefImpl::sort()
 
 static QCString encodeDirName(const QCString &anchor)
 {
+  AUTO_TRACE();
   // convert to md5 hash
-  uchar md5_sig[16];
+  uint8_t md5_sig[16];
   char sigStr[33];
-  MD5Buffer((const unsigned char *)anchor.data(),anchor.length(),md5_sig);
+  MD5Buffer(anchor.data(),anchor.length(),md5_sig);
   MD5SigToString(md5_sig,sigStr);
+  AUTO_TRACE_EXIT("result={}",sigStr);
   return sigStr;
 
   // old algorithm
@@ -209,22 +215,23 @@ static QCString encodeDirName(const QCString &anchor)
 
 QCString DirDefImpl::getOutputFileBase() const
 {
-  //printf("DirDefImpl::getOutputFileBase() %s->dir_%s\n",
-  //    qPrint(m_diskName),qPrint(encodeDirName(m_diskName)));
-  return "dir_"+encodeDirName(m_diskName);
+  QCString dir = "dir_"+encodeDirName(m_diskName);
+  AUTO_TRACE("diskName={} result={}",m_diskName,dir);
+  return dir;
 }
 
 void DirDefImpl::writeDetailedDescription(OutputList &ol,const QCString &title)
 {
+  AUTO_TRACE();
   if ((!briefDescription().isEmpty() && Config_getBool(REPEAT_BRIEF)) ||
       !documentation().isEmpty())
   {
     ol.pushGeneratorState();
-      ol.disable(OutputGenerator::Html);
+      ol.disable(OutputType::Html);
       ol.writeRuler();
     ol.popGeneratorState();
     ol.pushGeneratorState();
-      ol.disableAllBut(OutputGenerator::Html);
+      ol.disableAllBut(OutputType::Html);
       ol.writeAnchor(QCString(),"details");
     ol.popGeneratorState();
     ol.startGroupHeader();
@@ -242,12 +249,11 @@ void DirDefImpl::writeDetailedDescription(OutputList &ol,const QCString &title)
         !documentation().isEmpty())
     {
       ol.pushGeneratorState();
-        ol.disable(OutputGenerator::Man);
-        ol.disable(OutputGenerator::RTF);
-        // ol.newParagraph();  // FIXME:PARA
+        ol.disable(OutputType::Man);
+        ol.disable(OutputType::RTF);
         ol.enableAll();
-        ol.disableAllBut(OutputGenerator::Man);
-        ol.enable(OutputGenerator::Latex);
+        ol.disableAllBut(OutputType::Man);
+        ol.enable(OutputType::Latex);
         ol.writeString("\n\n");
       ol.popGeneratorState();
     }
@@ -263,30 +269,31 @@ void DirDefImpl::writeDetailedDescription(OutputList &ol,const QCString &title)
 
 void DirDefImpl::writeBriefDescription(OutputList &ol)
 {
+  AUTO_TRACE();
   if (hasBriefDescription())
   {
-    std::unique_ptr<IDocParser> parser { createDocParser() };
-    std::unique_ptr<DocRoot> rootNode  { validatingParseDoc(
+    auto parser { createDocParser() };
+    auto ast    { validatingParseDoc(
          *parser.get(), briefFile(),briefLine(),this,0,briefDescription(),TRUE,FALSE,
          QCString(),FALSE,FALSE,Config_getBool(MARKDOWN_SUPPORT)) };
-    if (rootNode && !rootNode->isEmpty())
+    if (!ast->isEmpty())
     {
       ol.startParagraph();
       ol.pushGeneratorState();
-      ol.disableAllBut(OutputGenerator::Man);
+      ol.disableAllBut(OutputType::Man);
       ol.writeString(" - ");
       ol.popGeneratorState();
-      ol.writeDoc(rootNode.get(),this,0);
+      ol.writeDoc(ast.get(),this,0);
       ol.pushGeneratorState();
-      ol.disable(OutputGenerator::RTF);
+      ol.disable(OutputType::RTF);
       ol.writeString(" \n");
-      ol.enable(OutputGenerator::RTF);
+      ol.enable(OutputType::RTF);
 
       if (Config_getBool(REPEAT_BRIEF) ||
           !documentation().isEmpty()
          )
       {
-        ol.disableAllBut(OutputGenerator::Html);
+        ol.disableAllBut(OutputType::Html);
         ol.startTextLink(QCString(),"details");
         ol.parseText(theTranslator->trMore());
         ol.endTextLink();
@@ -308,7 +315,7 @@ void DirDefImpl::writeDirectoryGraph(OutputList &ol)
     if (!dirDep.isTrivial())
     {
       msg("Generating dependency graph for directory %s\n",qPrint(displayName()));
-      ol.disable(OutputGenerator::Man);
+      ol.disable(OutputType::Man);
       //ol.startParagraph();
       ol.startDirDepGraph();
       ol.parseText(theTranslator->trDirDepGraph(shortName()));
@@ -321,6 +328,7 @@ void DirDefImpl::writeDirectoryGraph(OutputList &ol)
 
 void DirDefImpl::writeSubDirList(OutputList &ol)
 {
+  AUTO_TRACE();
   int numSubdirs = 0;
   for(const auto dd : m_subdirs)
   {
@@ -330,6 +338,7 @@ void DirDefImpl::writeSubDirList(OutputList &ol)
     }
   }
 
+  AUTO_TRACE_ADD("numSubdirs={}",numSubdirs);
   // write subdir list
   if (numSubdirs>0)
   {
@@ -339,14 +348,22 @@ void DirDefImpl::writeSubDirList(OutputList &ol)
     ol.startMemberList();
     for(const auto dd : m_subdirs)
     {
-      if (dd->hasDocumentation() || dd->getFiles().empty())
+      if (dd->hasDocumentation() || !dd->getFiles().empty())
       {
         ol.startMemberDeclaration();
-        ol.startMemberItem(dd->anchor(),0);
-        ol.parseText(theTranslator->trDir(FALSE,TRUE)+" ");
+        ol.startMemberItem(dd->anchor(),OutputGenerator::MemberItemType::Normal);
+        {
+          ol.pushGeneratorState();
+          ol.disableAllBut(OutputType::Html);
+          ol.writeString("<span class=\"iconfclosed\"></span>");
+          ol.enableAll();
+          ol.disable(OutputType::Html);
+          ol.parseText(theTranslator->trDir(FALSE,TRUE)+" ");
+          ol.popGeneratorState();
+        }
         ol.insertMemberAlign();
         ol.writeObjectLink(dd->getReference(),dd->getOutputFileBase(),QCString(),dd->shortName());
-        ol.endMemberItem();
+        ol.endMemberItem(OutputGenerator::MemberItemType::Normal);
         if (!dd->briefDescription().isEmpty() && Config_getBool(BRIEF_MEMBER_DESC))
         {
           ol.startMemberDescription(dd->getOutputFileBase());
@@ -370,15 +387,22 @@ void DirDefImpl::writeSubDirList(OutputList &ol)
 
 void DirDefImpl::writeFileList(OutputList &ol)
 {
+  AUTO_TRACE();
   int numFiles = 0;
   for (const auto &fd : m_fileList)
   {
-    if (fd->hasDocumentation())
+    bool genSourceFile;
+    if (fileVisibleInIndex(fd,genSourceFile))
+    {
+      numFiles++;
+    }
+    else if (genSourceFile)
     {
       numFiles++;
     }
   }
 
+  AUTO_TRACE_ADD("numFiles={}",numFiles);
   // write file list
   if (numFiles>0)
   {
@@ -388,11 +412,30 @@ void DirDefImpl::writeFileList(OutputList &ol)
     ol.startMemberList();
     for (const auto &fd : m_fileList)
     {
-      if (fd->hasDocumentation())
+      bool doc,src;
+      doc = fileVisibleInIndex(fd,src);
+      if (doc || src)
       {
         ol.startMemberDeclaration();
-        ol.startMemberItem(fd->anchor(),0);
-        ol.docify(theTranslator->trFile(FALSE,TRUE)+" ");
+        ol.startMemberItem(fd->anchor(),OutputGenerator::MemberItemType::Normal);
+        {
+          ol.pushGeneratorState();
+          ol.disableAllBut(OutputType::Html);
+          bool genSrc = fd->generateSourceFile();
+          if (genSrc)
+          {
+            ol.startTextLink(fd->includeName(),QCString());
+          }
+          ol.writeString("<span class=\"icondoc\"></span>");
+          if (genSrc)
+          {
+            ol.endTextLink();
+          }
+          ol.enableAll();
+          ol.disable(OutputType::Html);
+          ol.docify(theTranslator->trFile(FALSE,TRUE)+" ");
+          ol.popGeneratorState();
+        }
         ol.insertMemberAlign();
         if (fd->isLinkable())
         {
@@ -404,19 +447,7 @@ void DirDefImpl::writeFileList(OutputList &ol)
           ol.docify(fd->name());
           ol.endBold();
         }
-        if (fd->generateSourceFile())
-        {
-          ol.pushGeneratorState();
-          ol.disableAllBut(OutputGenerator::Html);
-          ol.docify(" ");
-          ol.startTextLink(fd->includeName(),QCString());
-          ol.docify("[");
-          ol.parseText(theTranslator->trCode());
-          ol.docify("]");
-          ol.endTextLink();
-          ol.popGeneratorState();
-        }
-        ol.endMemberItem();
+        ol.endMemberItem(OutputGenerator::MemberItemType::Normal);
         if (!fd->briefDescription().isEmpty() && Config_getBool(BRIEF_MEMBER_DESC))
         {
           ol.startMemberDescription(fd->getOutputFileBase());
@@ -454,7 +485,7 @@ QCString DirDefImpl::shortTitle() const
 
 bool DirDefImpl::hasDetailedDescription() const
 {
-  static bool repeatBrief = Config_getBool(REPEAT_BRIEF);
+  bool repeatBrief = Config_getBool(REPEAT_BRIEF);
   return (!briefDescription().isEmpty() && repeatBrief) || !documentation().isEmpty();
 }
 
@@ -462,8 +493,10 @@ void DirDefImpl::writeTagFile(TextStream &tagFile)
 {
   tagFile << "  <compound kind=\"dir\">\n";
   tagFile << "    <name>" << convertToXML(displayName()) << "</name>\n";
-  tagFile << "    <path>" << convertToXML(name()) << "</path>\n";
-  tagFile << "    <filename>" << convertToXML(getOutputFileBase()) << Doxygen::htmlFileExtension << "</filename>\n";
+  tagFile << "    <path>" << convertToXML(stripFromPath(name())) << "</path>\n";
+  QCString fn=getOutputFileBase();
+  addHtmlExtensionIfMissing(fn);
+  tagFile << "    <filename>" << fn << "</filename>\n";
   for (const auto &lde : LayoutDocManager::instance().docEntries(LayoutDocManager::Directory))
   {
     switch (lde->kind())
@@ -497,11 +530,12 @@ void DirDefImpl::writeTagFile(TextStream &tagFile)
 
 void DirDefImpl::writeDocumentation(OutputList &ol)
 {
-  static bool generateTreeView = Config_getBool(GENERATE_TREEVIEW);
+  bool generateTreeView = Config_getBool(GENERATE_TREEVIEW);
   ol.pushGeneratorState();
 
   QCString title=theTranslator->trDirReference(m_dispName);
-  startFile(ol,getOutputFileBase(),name(),title,HLI_Files,!generateTreeView);
+  AUTO_TRACE("title={}",title);
+  startFile(ol,getOutputFileBase(),name(),title,HighlightedItem::Files,!generateTreeView);
 
   if (!generateTreeView)
   {
@@ -512,10 +546,10 @@ void DirDefImpl::writeDocumentation(OutputList &ol)
 
   startTitle(ol,getOutputFileBase());
   ol.pushGeneratorState();
-    ol.disableAllBut(OutputGenerator::Html);
+    ol.disableAllBut(OutputType::Html);
     ol.parseText(shortTitle());
     ol.enableAll();
-    ol.disable(OutputGenerator::Html);
+    ol.disable(OutputType::Html);
     ol.parseText(title);
   ol.popGeneratorState();
   endTitle(ol,getOutputFileBase(),title);
@@ -548,8 +582,11 @@ void DirDefImpl::writeDocumentation(OutputList &ol)
         break;
       case LayoutDocEntry::DetailedDesc:
         {
-          const LayoutDocEntrySection *ls = (const LayoutDocEntrySection*)lde.get();
-          writeDetailedDescription(ol,ls->title(lang));
+          const LayoutDocEntrySection *ls = dynamic_cast<const LayoutDocEntrySection*>(lde.get());
+          if (ls)
+          {
+            writeDetailedDescription(ol,ls->title(lang));
+          }
         }
         break;
       case LayoutDocEntry::ClassIncludes:
@@ -605,7 +642,7 @@ void DirDefImpl::writeDocumentation(OutputList &ol)
 
   ol.endContents();
 
-  endFileWithNavPath(this,ol);
+  endFileWithNavPath(ol,this);
 
   ol.popGeneratorState();
 }
@@ -629,17 +666,18 @@ void DirDefImpl::setLevel()
 
 /** Add as "uses" dependency between \a this dir and \a dir,
  *  that was caused by a dependency on file \a fd.
+ *  srcDirect and dstDirect indicate if it is a direct dependencies (true) or if
+ *  the dependencies was indirect (e.g. a parent dir that has a child dir that has the dependencies)
  */
 void DirDefImpl::addUsesDependency(const DirDef *dir,const FileDef *srcFd,
-                                   const FileDef *dstFd,bool inherited)
+                                   const FileDef *dstFd,bool srcDirect, bool dstDirect)
 {
   if (this==dir) return; // do not add self-dependencies
-  //static int count=0;
-  //printf("  %d add dependency %s->%s due to %s->%s\n",
-  //    count++,qPrint(shortName()),
-  //    qPrint(dir->shortName()),
-  //    qPrint(srcFd->name()),
-  //    qPrint(dstFd->name()));
+  AUTO_TRACE("add dependency {}->{} due to {}->{}",
+      qPrint(shortName()),
+      qPrint(dir->shortName()),
+      qPrint(srcFd->name()),
+      qPrint(dstFd->name()));
 
   // levels match => add direct dependency
   bool added=FALSE;
@@ -649,8 +687,8 @@ void DirDefImpl::addUsesDependency(const DirDef *dir,const FileDef *srcFd,
      const FilePair *usedPair = usedDir->findFilePair(FilePair::key(srcFd,dstFd));
      if (usedPair==0) // new file dependency
      {
-       //printf("  => new file\n");
-       usedDir->addFileDep(srcFd,dstFd);
+       AUTO_TRACE_ADD("{} => {} new file dependency",srcFd->name(),dstFd->name());
+       usedDir->addFileDep(srcFd,dstFd, srcDirect, dstDirect);
        added=TRUE;
      }
      else
@@ -660,10 +698,10 @@ void DirDefImpl::addUsesDependency(const DirDef *dir,const FileDef *srcFd,
   }
   else // new directory dependency
   {
-    //printf("  => new file\n");
-    auto newUsedDir = std::make_unique<UsedDir>(dir,inherited);
-    newUsedDir->addFileDep(srcFd,dstFd);
-    usedDir = m_usedDirs.add(dir->getOutputFileBase(),std::move(newUsedDir));
+    AUTO_TRACE_ADD("{} => {} new file dependency",srcFd->name(),dstFd->name());
+    auto newUsedDir = std::make_unique<UsedDir>(dir);
+    newUsedDir->addFileDep(srcFd,dstFd, srcDirect, dstDirect);
+    m_usedDirs.add(dir->getOutputFileBase(),std::move(newUsedDir));
     added=TRUE;
   }
   if (added)
@@ -671,12 +709,20 @@ void DirDefImpl::addUsesDependency(const DirDef *dir,const FileDef *srcFd,
     if (dir->parent())
     {
       // add relation to parent of used dir
-      addUsesDependency(dir->parent(),srcFd,dstFd,inherited);
+      addUsesDependency(dir->parent(),
+                        srcFd,
+                        dstFd,
+                        srcDirect,
+                        false); // indirect dependency on dest dir
     }
     if (parent())
     {
       // add relation for the parent of this dir as well
-      parent()->addUsesDependency(dir,srcFd,dstFd,TRUE);
+      parent()->addUsesDependency(dir,
+                                 srcFd,
+                                 dstFd,
+                                 false, // indirect dependency from source dir
+                                 dstDirect);
     }
   }
 }
@@ -685,23 +731,21 @@ void DirDefImpl::addUsesDependency(const DirDef *dir,const FileDef *srcFd,
  */
 void DirDefImpl::computeDependencies()
 {
+  AUTO_TRACE();
   for (const auto &fd : m_fileList)
   {
-    //printf("  File %s\n",qPrint(fd->name()));
-    //printf("** dir=%s file=%s\n",qPrint(shortName()),qPrint(fd->name()));
+    AUTO_TRACE_ADD("dir={} file={}",shortName(),fd->name());
     for (const auto &ii : fd->includeFileList())
     {
-      //printf("  > %s\n",qPrint(ii->includeName));
-      //printf("    #include %s\n",qPrint(ii->includeName));
+      AUTO_TRACE_ADD("#include {}",ii.includeName);
       if (ii.fileDef && ii.fileDef->isLinkable()) // linkable file
       {
         DirDef *usedDir = ii.fileDef->getDirDef();
         if (usedDir)
         {
           // add dependency: thisDir->usedDir
-          //static int count=0;
-          //printf("      %d: add dependency %s->%s\n",count++,qPrint(name()),qPrint(usedDir->name()));
-          addUsesDependency(usedDir,fd,ii.fileDef,FALSE);
+          AUTO_TRACE_ADD("add dependency {}->{}",name(),usedDir->name());
+          addUsesDependency(usedDir,fd,ii.fileDef,true,true);
         }
       }
     }
@@ -729,14 +773,14 @@ bool DirDefImpl::isParentOf(const DirDef *dir) const
 
 bool DirDefImpl::depGraphIsTrivial() const
 {
-  return m_usedDirs.empty();
+  return m_usedDirs.empty() && m_parent==nullptr;
 }
 
 
 //----------------------------------------------------------------------
 
-UsedDir::UsedDir(const DirDef *dir,bool inherited) :
-   m_dir(dir), m_inherited(inherited)
+UsedDir::UsedDir(const DirDef *dir) :
+   m_dir(dir)
 {
 }
 
@@ -744,9 +788,12 @@ UsedDir::~UsedDir()
 {
 }
 
-void UsedDir::addFileDep(const FileDef *srcFd,const FileDef *dstFd)
+void UsedDir::addFileDep(const FileDef *srcFd,const FileDef *dstFd, bool srcDirect, bool dstDirect)
 {
   m_filePairs.add(FilePair::key(srcFd,dstFd),std::make_unique<FilePair>(srcFd,dstFd));
+  m_hasDirectDeps    = m_hasDirectDeps    || (srcDirect && dstDirect);
+  m_hasDirectSrcDeps = m_hasDirectSrcDeps || srcDirect;
+  m_hasDirectDstDeps = m_hasDirectDstDeps || dstDirect;
 }
 
 void UsedDir::sort()
@@ -769,6 +816,7 @@ FilePair *UsedDir::findFilePair(const QCString &name)
 
 DirDef *DirDefImpl::createNewDir(const QCString &path)
 {
+  AUTO_TRACE();
   ASSERT(path!=0);
   DirDef *dir = Doxygen::dirLinkedMap->find(path);
   if (dir==0) // new dir
@@ -776,8 +824,7 @@ DirDef *DirDefImpl::createNewDir(const QCString &path)
     dir = Doxygen::dirLinkedMap->add(path,
             std::unique_ptr<DirDef>(
               createDirDef(path)));
-    //printf("Adding new dir %s\n",path);
-    //printf("createNewDir %s short=%s\n",path,qPrint(dir->shortName()));
+    AUTO_TRACE_ADD("Adding new dir {} shortName {}",path,dir->shortName());
   }
   return dir;
 }
@@ -800,7 +847,7 @@ bool DirDefImpl::matchPath(const QCString &path,const StringVector &l)
  */
 DirDef *DirDefImpl::mergeDirectoryInTree(const QCString &path)
 {
-  //printf("DirDefImpl::mergeDirectoryInTree(%s)\n",qPrint(path));
+  AUTO_TRACE("path={}",path);
   int p=0,i=0;
   DirDef *dir=0;
   while ((i=path.find('/',p))!=-1)
@@ -855,16 +902,17 @@ static void writePartialFilePath(OutputList &ol,const DirDef *root,const FileDef
 
 void DirRelation::writeDocumentation(OutputList &ol)
 {
-  static bool generateTreeView = Config_getBool(GENERATE_TREEVIEW);
+  bool generateTreeView = Config_getBool(GENERATE_TREEVIEW);
   ol.pushGeneratorState();
-  ol.disableAllBut(OutputGenerator::Html);
+  ol.disableAllBut(OutputType::Html);
 
   QCString shortTitle=theTranslator->trDirRelation(
                       (m_src->shortName()+" &rarr; "+m_dst->dir()->shortName()));
   QCString title=theTranslator->trDirRelation(
                  (m_src->displayName()+" -> "+m_dst->dir()->shortName()));
+  AUTO_TRACE("title={}",title);
   startFile(ol,getOutputFileBase(),getOutputFileBase(),
-            title,HLI_None,!generateTreeView,m_src->getOutputFileBase());
+            title,HighlightedItem::None,!generateTreeView,m_src->getOutputFileBase());
 
   if (!generateTreeView)
   {
@@ -900,7 +948,7 @@ void DirRelation::writeDocumentation(OutputList &ol)
 
   ol.endContents();
 
-  endFileWithNavPath(m_src,ol);
+  endFileWithNavPath(ol,m_src);
 
   ol.popGeneratorState();
 }
@@ -913,13 +961,14 @@ void DirRelation::writeDocumentation(OutputList &ol)
  */
 static void computeCommonDirPrefix()
 {
+  AUTO_TRACE();
   QCString path;
   auto it = Doxygen::dirLinkedMap->begin();
   if (!Doxygen::dirLinkedMap->empty()) // we have at least one dir
   {
     // start will full path of first dir
     path=(*it)->name();
-    int i=path.findRev('/',(int)path.length()-2);
+    int i=path.findRev('/',path.length()-2);
     path=path.left(i+1);
     bool done=FALSE;
     if (i==-1)
@@ -930,7 +979,7 @@ static void computeCommonDirPrefix()
     {
       while (!done)
       {
-        uint l = path.length();
+        uint32_t l = path.length();
         size_t count=0;
         for (const auto &dir : *Doxygen::dirLinkedMap)
         {
@@ -939,7 +988,7 @@ static void computeCommonDirPrefix()
           {
             if (dirName.left(l)!=path) // dirName does not start with path
             {
-              i=path.findRev('/',(int)l-2);
+              i=path.findRev('/',l-2);
               if (i==-1) // no unique prefix -> stop
               {
                 path="";
@@ -956,7 +1005,7 @@ static void computeCommonDirPrefix()
           {
             path=dir->name();
             l=path.length();
-            i=path.findRev('/',(int)l-2);
+            i=path.findRev('/',l-2);
             if (i==-1) // no unique prefix -> stop
             {
               path="";
@@ -982,18 +1031,18 @@ static void computeCommonDirPrefix()
   {
     QCString diskName = dir->name().right(dir->name().length()-path.length());
     dir->setDiskName(diskName);
-    //printf("set disk name: %s -> %s\n",qPrint(dir->name()),qPrint(diskName));
+    AUTO_TRACE_ADD("set disk name: {} -> {}",dir->name(),diskName);
   }
 }
 
 void buildDirectories()
 {
+  AUTO_TRACE();
   // for each input file
   for (const auto &fn : *Doxygen::inputNameLinkedMap)
   {
     for (const auto &fd : *fn)
     {
-      //printf("buildDirectories %s\n",qPrint(fd->name()));
       if (fd->getReference().isEmpty())
       {
         DirDef *dir;
@@ -1014,7 +1063,7 @@ void buildDirectories()
   for (const auto &dir : *Doxygen::dirLinkedMap)
   {
     QCString name = dir->name();
-    int i=name.findRev('/',(int)name.length()-2);
+    int i=name.findRev('/',name.length()-2);
     if (i>0)
     {
       DirDef *parent = Doxygen::dirLinkedMap->find(name.left(i+1));
@@ -1022,8 +1071,8 @@ void buildDirectories()
       if (parent)
       {
         parent->addSubDir(dir.get());
-        //printf("DirDefImpl::addSubdir(): Adding subdir\n%s to\n%s\n",
-        //  qPrint(dir->displayName()), qPrint(parent->displayName()));
+        AUTO_TRACE_ADD("DirDefImpl::addSubdir(): Adding subdir {} to {}",
+                        dir->displayName(), parent->displayName());
       }
     }
   }
@@ -1038,35 +1087,54 @@ void buildDirectories()
   std::sort(Doxygen::dirLinkedMap->begin(),
             Doxygen::dirLinkedMap->end(),
             [](const auto &d1,const auto &d2)
-            { return qstricmp(d1->shortName(),d2->shortName()) < 0; });
+            {
+              QCString s1 = d1->shortName(), s2 = d2->shortName();
+              int i = qstricmp(s1,s2);
+              if (i==0) // if sort name are equal, sort on full path
+              {
+                QCString n1 = d1->name(), n2 = d2->name();
+                int n = qstricmp(n1,n2);
+                return n < 0;
+              }
+              return i < 0;
+            });
+
+  // set the directory count identifier
+  int dirCount=0;
+  for (const auto &dir : *Doxygen::dirLinkedMap)
+  {
+    dir->setDirCount(dirCount++);
+  }
 
   computeCommonDirPrefix();
 }
 
 void computeDirDependencies()
 {
+  AUTO_TRACE();
   // compute nesting level for each directory
   for (const auto &dir : *Doxygen::dirLinkedMap)
   {
     dir->setLevel();
   }
+
   // compute uses dependencies between directories
   for (const auto &dir : *Doxygen::dirLinkedMap)
   {
-    //printf("computeDependencies for %s: #dirs=%d\n",qPrint(dir->name()),Doxygen::directories.count());
+    AUTO_TRACE_ADD("computeDependencies for {}: #dirs={}",dir->name(),Doxygen::dirLinkedMap->size());
     dir->computeDependencies();
   }
-
 }
 
 void generateDirDocs(OutputList &ol)
 {
+  AUTO_TRACE();
   for (const auto &dir : *Doxygen::dirLinkedMap)
   {
     ol.pushGeneratorState();
     if (!dir->hasDocumentation())
     {
-      ol.disableAllBut(OutputGenerator::Html);
+      ol.disableAllBut(OutputType::Html);
     }
     dir->writeDocumentation(ol);
     ol.popGeneratorState();
