@@ -31,6 +31,7 @@
 #include "utf8.h"
 #include "datetime.h"
 #include "portable.h"
+#include "outputlist.h"
 
 static QCString getExtension()
 {
@@ -107,16 +108,26 @@ static QCString objectLinkToString(const QCString &text)
 
 //-------------------------------------------------------------------------------
 
+ManCodeGenerator::ManCodeGenerator(TextStream *t) : m_t(t)
+{
+}
+
 void ManCodeGenerator::startCodeFragment(const QCString &)
 {
-  m_t << ".PP\n";
-  m_t << ".nf\n";
+  *m_t << ".PP\n";
+  *m_t << ".nf\n";
 }
 
 void ManCodeGenerator::endCodeFragment(const QCString &)
 {
-  if (m_col>0) m_t << "\n";
-  m_t << ".fi\n";
+  if (m_col>0) *m_t << "\n";
+  *m_t << ".fi\n";
+  m_col=0;
+}
+
+void ManCodeGenerator::writeLineNumber(const QCString &,const QCString &,const QCString &,int l, bool)
+{
+  *m_t << l << " ";
   m_col=0;
 }
 
@@ -133,12 +144,12 @@ void ManCodeGenerator::writeCodeLink(CodeSymbolType,
     {
       switch(c)
       {
-        case '-':  m_t << "\\-"; break; // see  bug747780
-        case '.':  m_t << "\\&."; break; // see  bug652277
-        case '\\': m_t << "\\\\"; m_col++; break;
-        case '\n': m_t << "\n"; m_col=0; break;
+        case '-':  *m_t << "\\-"; break; // see  bug747780
+        case '.':  *m_t << "\\&."; break; // see  bug652277
+        case '\\': *m_t << "\\\\"; m_col++; break;
+        case '\n': *m_t << "\n"; m_col=0; break;
         case '\"':  c = '\''; // no break!
-        default: m_t << c; m_col++; break;
+        default: *m_t << c; m_col++; break;
       }
     }
     //printf("%s",str);fflush(stdout);
@@ -158,17 +169,17 @@ void ManCodeGenerator::codify(const QCString &str)
       c=*p++;
       switch(c)
       {
-        case '-':  m_t << "\\-"; break; // see  bug747780
-        case '.':   m_t << "\\&."; break; // see  bug652277
+        case '-':  *m_t << "\\-"; break; // see  bug747780
+        case '.':   *m_t << "\\&."; break; // see  bug652277
         case '\t':  spacesToNextTabStop =
                           Config_getInt(TAB_SIZE) - (m_col%Config_getInt(TAB_SIZE));
-                    m_t << Doxygen::spaces.left(spacesToNextTabStop);
+                    *m_t << Doxygen::spaces.left(spacesToNextTabStop);
                     m_col+=spacesToNextTabStop;
                     break;
-        case '\n':  m_t << "\n"; m_col=0; break;
-        case '\\':  m_t << "\\\\"; m_col++; break;
+        case '\n':  *m_t << "\n"; m_col=0; break;
+        case '\\':  *m_t << "\\\\"; m_col++; break;
         case '\"':  // no break!
-        default:    p=writeUTF8Char(m_t,p-1); m_col++; break;
+        default:    p=writeUTF8Char(*m_t,p-1); m_col++; break;
       }
     }
     //printf("%s",str);fflush(stdout);
@@ -180,31 +191,65 @@ void ManCodeGenerator::codify(const QCString &str)
 
 ManGenerator::ManGenerator()
   : OutputGenerator(Config_getString(MAN_OUTPUT)+"/"+getSubdir())
-  , m_codeGen(m_t)
+  , m_codeList(std::make_unique<OutputCodeList>())
 {
+  m_codeGen = m_codeList->add<ManCodeGenerator>(&m_t);
 }
 
-ManGenerator::ManGenerator(const ManGenerator &og)
-  : OutputGenerator(og)
-  , m_codeGen(m_t)
+ManGenerator::ManGenerator(const ManGenerator &og) : OutputGenerator(og.m_dir)
 {
+  m_codeList = std::make_unique<OutputCodeList>(*og.m_codeList);
+  m_codeGen      = m_codeList->get<ManCodeGenerator>();
+  m_codeGen->setTextStream(&m_t);
+  m_firstCol      = og.m_firstCol;
+  m_col           = og.m_col;
+  m_paragraph     = og.m_paragraph;
+  m_upperCase     = og.m_upperCase;
+  m_insideTabbing = og.m_insideTabbing;
+  m_inHeader      = og.m_inHeader;
 }
 
 ManGenerator &ManGenerator::operator=(const ManGenerator &og)
 {
-  OutputGenerator::operator=(og);
+  if (this!=&og)
+  {
+    m_dir           = og.m_dir;
+    m_codeList = std::make_unique<OutputCodeList>(*og.m_codeList);
+    m_codeGen       = m_codeList->get<ManCodeGenerator>();
+    m_codeGen->setTextStream(&m_t);
+    m_firstCol      = og.m_firstCol;
+    m_col           = og.m_col;
+    m_paragraph     = og.m_paragraph;
+    m_upperCase     = og.m_upperCase;
+    m_insideTabbing = og.m_insideTabbing;
+    m_inHeader      = og.m_inHeader;
+  }
   return *this;
 }
 
-std::unique_ptr<OutputGenerator> ManGenerator::clone() const
+ManGenerator::ManGenerator(ManGenerator &&og)
+  : OutputGenerator(std::move(og))
 {
-  return std::make_unique<ManGenerator>(*this);
+  m_codeList      = std::exchange(og.m_codeList,std::unique_ptr<OutputCodeList>());
+  m_codeGen       = m_codeList->get<ManCodeGenerator>();
+  m_codeGen->setTextStream(&m_t);
+  m_firstCol      = std::exchange(og.m_firstCol,true);
+  m_col           = std::exchange(og.m_col,0);
+  m_paragraph     = std::exchange(og.m_paragraph,true);
+  m_upperCase     = std::exchange(og.m_upperCase,false);
+  m_insideTabbing = std::exchange(og.m_insideTabbing,false);
+  m_inHeader      = std::exchange(og.m_inHeader,false);
 }
 
 ManGenerator::~ManGenerator()
 {
 }
 
+void ManGenerator::addCodeGen(OutputCodeList &list)
+{
+  list.add(OutputCodeList::OutputCodeVariant(ManCodeGeneratorDefer(m_codeGen)));
+}
+
 void ManGenerator::init()
 {
   QCString manOutput = Config_getString(MAN_OUTPUT);
@@ -270,7 +315,7 @@ static QCString buildFileName(const QCString &name)
   return fileName;
 }
 
-void ManGenerator::startFile(const QCString &,const QCString &manName,const QCString &,int)
+void ManGenerator::startFile(const QCString &,const QCString &manName,const QCString &,int,int)
 {
   startPlainFile( buildFileName( manName ) );
   m_firstCol=TRUE;
@@ -284,8 +329,19 @@ void ManGenerator::endFile()
 
 void ManGenerator::endTitleHead(const QCString &,const QCString &name)
 {
-  m_t << ".TH \"" << name << "\" " << getExtension() << " \""
-    << dateToString(DateTimeType::Date) << "\" \"";
+  m_t << ".TH \"" << name << "\" " << getExtension();
+  switch (Config_getEnum(TIMESTAMP))
+  {
+    case TIMESTAMP_t::YES:
+    case TIMESTAMP_t::DATETIME:
+      m_t << " \"" << dateToString(DateTimeType::DateTime) << "\" \"";
+      break;
+    case TIMESTAMP_t::DATE:
+      m_t << " \"" << dateToString(DateTimeType::Date) << "\" \"";
+      break;
+    case TIMESTAMP_t::NO:
+      break;
+  }
   if (!Config_getString(PROJECT_NUMBER).isEmpty())
     m_t << "Version " << Config_getString(PROJECT_NUMBER) << "\" \"";
   if (Config_getString(PROJECT_NAME).isEmpty())
@@ -352,14 +408,6 @@ void ManGenerator::writeObjectLink(const QCString &,const QCString &,
   startBold(); docify(name); endBold();
 }
 
-void ManGenerator::startHtmlLink(const QCString &)
-{
-}
-
-void ManGenerator::endHtmlLink()
-{
-}
-
 void ManGenerator::startGroupHeader(int)
 {
   if (!m_firstCol) m_t << "\n";
@@ -427,17 +475,6 @@ void ManGenerator::writeChar(char c)
   m_paragraph=FALSE;
 }
 
-void ManGenerator::startDescList(SectionTypes)
-{
-  if (!m_firstCol)
-  { m_t << "\n" << ".PP\n";
-    m_firstCol=TRUE; m_paragraph=TRUE;
-    m_col=0;
-  }
-  m_paragraph=FALSE;
-  startBold();
-}
-
 void ManGenerator::startTitle()
 {
   if (!m_firstCol) m_t << "\n";
@@ -509,21 +546,7 @@ void ManGenerator::endMemberDoc(bool)
     m_t << "\"\n";
 }
 
-void ManGenerator::startSubsection()
-{
-  if (!m_firstCol) m_t << "\n";
-  m_t << ".SS \"";
-  m_firstCol=FALSE;
-  m_paragraph=FALSE;
-}
-
-void ManGenerator::endSubsection()
-{
-  m_t << "\"";
-}
-
-
-void ManGenerator::startSubsubsection()
+void ManGenerator::startCompoundTemplateParams()
 {
   if (!m_firstCol) m_t << "\n";
   m_t << "\n.SS \"";
@@ -531,11 +554,10 @@ void ManGenerator::startSubsubsection()
   m_paragraph=FALSE;
 }
 
-void ManGenerator::endSubsubsection()
+void ManGenerator::endCompoundTemplateParams()
 {
   m_t << "\"";
 }
-
 void ManGenerator::writeSynopsis()
 {
   if (!m_firstCol) m_t << "\n";
@@ -544,13 +566,6 @@ void ManGenerator::writeSynopsis()
   m_paragraph=FALSE;
 }
 
-void ManGenerator::startDescItem()
-{
-  if (!m_firstCol) m_t << "\n";
-  m_t << ".IP \"";
-  m_firstCol=FALSE;
-}
-
 void ManGenerator::startDescForItem()
 {
   if (!m_firstCol) m_t << "\n";
@@ -565,12 +580,6 @@ void ManGenerator::endDescForItem()
 {
 }
 
-void ManGenerator::endDescItem()
-{
-  m_t << "\" 1c\n";
-  m_firstCol=TRUE;
-}
-
 void ManGenerator::startAnonTypeScope(int indentLevel)
 {
   if (indentLevel==0)
@@ -588,14 +597,14 @@ void ManGenerator::endAnonTypeScope(int indentLevel)
 }
 
 
-void ManGenerator::startMemberItem(const QCString &,int,const QCString &)
+void ManGenerator::startMemberItem(const QCString &,MemberItemType,const QCString &)
 {
   if (m_firstCol && !m_insideTabbing) m_t << ".in +1c\n";
   m_t << "\n.ti -1c\n.RI \"";
   m_firstCol=FALSE;
 }
 
-void ManGenerator::endMemberItem()
+void ManGenerator::endMemberItem(MemberItemType)
 {
   m_t << "\"\n.br";
 }
@@ -724,30 +733,12 @@ void ManGenerator::endDescTable()
   endDescForItem();
 }
 
-void ManGenerator::startParamList(ParamListTypes,const QCString &title)
-{
-  if (!m_firstCol)
-  { m_t << "\n.PP\n";
-    m_firstCol=TRUE; m_paragraph=TRUE;
-    m_col=0;
-  }
-  m_paragraph=FALSE;
-  startBold();
-  docify(title);
-  endBold();
-  m_paragraph=TRUE;
-}
-
-void ManGenerator::endParamList()
-{
-}
-
 void ManGenerator::writeDoc(const IDocNodeAST *ast,const Definition *ctx,const MemberDef *,int)
 {
   const DocNodeAST *astImpl = dynamic_cast<const DocNodeAST *>(ast);
   if (astImpl)
   {
-    ManDocVisitor visitor(m_t,m_codeGen,ctx?ctx->getDefFileExtension():QCString(""));
+    ManDocVisitor visitor(m_t,*m_codeList,ctx?ctx->getDefFileExtension():QCString(""));
     std::visit(visitor,astImpl->root);
   }
   m_firstCol=FALSE;
@@ -897,9 +888,9 @@ void ManGenerator::endHeaderSection()
 }
 
 void ManGenerator::writeInheritedSectionTitle(
-                  const QCString &id,    const QCString &ref,
-                  const QCString &file,  const QCString &anchor,
-                  const QCString &title, const QCString &name)
+                  const QCString &/*id*/,    const QCString &/*ref*/,
+                  const QCString &/*file*/,  const QCString &/*anchor*/,
+                  const QCString &title,     const QCString &name)
 {
   m_t << "\n\n";
   m_t << theTranslator->trInheritedFrom(docifyToString(title), objectLinkToString(name));
