@@ -20,6 +20,8 @@
 
 #include "classdef.h"
 #include "config.h"
+#include "datetime.h"
+#include "index.h"
 
 /** Abstract base class for all translatable text fragments. */
 class Translator
@@ -80,6 +82,8 @@ class Translator
     virtual QCString trISOLang() = 0;
 
     /** language codes for Html help
+ 
+       <pre>
        0x402 Bulgarian
        0x405 Czech
        0x406 Danish
@@ -112,8 +116,10 @@ class Translator
        0x412 Korean
        0x804 Chinese (PRC)
        0x404 Chinese (Taiwan)
+       </pre>
 
        New LCIDs:
+       <pre>
        0x421 Indonesian
        0x41A Croatian
        0x418 Romanian
@@ -128,17 +134,22 @@ class Translator
        0x42A Vietnamese
        0x429 Persian (Iran)
        0xC01 Arabic (Egypt) - I don't know which version of arabic is used inside translator_ar.h ,
-       so I have chosen Egypt at random
+             so I have chosen Egypt at random
+       </pre>
 
       Code for Esperanto should be as shown below but the htmlhelp compiler 1.3 does not support this
       (and no newer version is available).
+      <pre>
       0x48f Esperanto
+      </pre>
       So do a fallback to the default language
+      <pre>
       0x409 English (United States)
+      </pre>
 
-
+      <pre>
       0xC1A Serbian (Serbia, Cyrillic)
-
+      </pre>
     */
     virtual QCString getLanguageString() = 0;
 
@@ -152,6 +163,7 @@ class Translator
     virtual QCString trRelatedFunctions() = 0;
     virtual QCString trRelatedSubscript() = 0;
     virtual QCString trDetailedDescription() = 0;
+    virtual QCString trDetails() = 0;
     virtual QCString trMemberTypedefDocumentation() = 0;
     virtual QCString trMemberEnumerationDocumentation() = 0;
     virtual QCString trMemberFunctionDocumentation() = 0;
@@ -196,7 +208,6 @@ class Translator
     virtual QCString trModuleDocumentation() = 0;
     virtual QCString trClassDocumentation() = 0;
     virtual QCString trFileDocumentation() = 0;
-    virtual QCString trExampleDocumentation() = 0;
     virtual QCString trReferenceManual() = 0;
     virtual QCString trDefines() = 0;
     virtual QCString trTypedefs() = 0;
@@ -605,7 +616,7 @@ class Translator
     virtual QCString trIncludesFileIn(const QCString &name) = 0;
     virtual QCString trDateTime(int year,int month,int day,int dayOfWeek,
                                 int hour,int minutes,int seconds,
-                                bool includeTime) = 0;
+                                DateTimeType includeTime) = 0;
     virtual QCString trDayOfWeek(int dayOfWeek, bool first_capital, bool full) = 0;
     virtual QCString trMonth(int month, bool first_capital, bool full) = 0;
     virtual QCString trDayPeriod(int period) = 0;
@@ -665,7 +676,7 @@ class Translator
     virtual QCString trDesignUnitIndex() = 0;
     virtual QCString trDesignUnits() = 0;
     virtual QCString trFunctionAndProc() = 0;
-    virtual QCString trVhdlType(uint64 type,bool single) = 0;
+    virtual QCString trVhdlType(uint64_t type,bool single) = 0;
     virtual QCString trCustomReference(const QCString &name) = 0;
 
     virtual QCString trConstants() = 0;
@@ -720,6 +731,26 @@ class Translator
 // new since 1.9.4
 //////////////////////////////////////////////////////////////////////////
     virtual QCString trPackageList() = 0;
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.9.6
+//////////////////////////////////////////////////////////////////////////
+    virtual QCString trFlowchart() = 0;
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.9.7
+//////////////////////////////////////////////////////////////////////////
+    virtual QCString trRelatedSymbols() = 0;
+    virtual QCString trRelatedSymbolsSubscript() = 0;
+    virtual QCString trRelatedSymbolDocumentation() = 0;
+
+    virtual QCString trCompoundType(ClassDef::CompoundType compType, SrcLangExt lang) = 0;
+
+    virtual QCString trFileMembersDescriptionTotal(FileMemberHighlight::Enum hl) = 0;
+    virtual QCString trCompoundMembersDescriptionTotal(ClassMemberHighlight::Enum hl) = 0;
+    virtual QCString trNamespaceMembersDescriptionTotal(NamespaceMemberHighlight::Enum hl) = 0;
+    virtual QCString trDefinition() = 0;
+    virtual QCString trDeclaration() = 0;
 };
 
 #endif
