@@ -24,6 +24,7 @@
 #include "util.h"
 #include "defargs.h"
 #include "outputgen.h"
+#include "outputlist.h"
 #include "dot.h"
 #include "dotclassgraph.h"
 #include "dotincldepgraph.h"
@@ -47,6 +48,8 @@
 #include "resourcemgr.h"
 #include "dir.h"
 #include "utf8.h"
+#include "portable.h"
+#include "outputlist.h"
 
 // no debug info
 #define XML_DB(x) do {} while(0)
@@ -123,7 +126,7 @@ inline void writeXMLCodeString(TextStream &t,const QCString &str, int &col)
     {
       case '\t':
       {
-        static int tabSize = Config_getInt(TAB_SIZE);
+        int tabSize = Config_getInt(TAB_SIZE);
 	int spacesToNextTabStop = tabSize - (col%tabSize);
 	col+=spacesToNextTabStop;
 	while (spacesToNextTabStop--) t << "<sp/>";
@@ -162,7 +165,7 @@ static void writeCombineScript()
 {
   QCString outputDirectory = Config_getString(XML_OUTPUT);
   QCString fileName=outputDirectory+"/combine.xslt";
-  std::ofstream t(fileName.str(),std::ofstream::out | std::ofstream::binary);
+  std::ofstream t = Portable::openOutputStream(fileName);
   if (!t.is_open())
   {
     err("Cannot open file %s for writing!\n",qPrint(fileName));
@@ -225,21 +228,25 @@ class TextGeneratorXMLImpl : public TextGeneratorIntf
 
 //-------------------------------------------------------------------------------------------
 
-XMLCodeGenerator::XMLCodeGenerator(TextStream &t) : m_t(t), m_lineNumber(-1), m_isMemberRef(FALSE), m_col(0),
+XMLCodeGenerator::XMLCodeGenerator(TextStream *t) : m_t(t), m_lineNumber(-1), m_isMemberRef(FALSE), m_col(0),
       m_insideCodeLine(FALSE), m_normalHLNeedStartTag(TRUE), m_insideSpecialHL(FALSE)
 {
 }
 
+XMLCodeGenerator::~XMLCodeGenerator()
+{
+}
+
 /** Generator for producing XML formatted source code. */
 void XMLCodeGenerator::codify(const QCString &text)
 {
   XML_DB(("(codify \"%s\")\n",text));
   if (m_insideCodeLine && !m_insideSpecialHL && m_normalHLNeedStartTag)
   {
-    m_t << "<highlight class=\"normal\">";
+    *m_t << "<highlight class=\"normal\">";
     m_normalHLNeedStartTag=FALSE;
   }
-  writeXMLCodeString(m_t,text,m_col);
+  writeXMLCodeString(*m_t,text,m_col);
 }
 void XMLCodeGenerator::writeCodeLink(CodeSymbolType,
                    const QCString &ref,const QCString &file,
@@ -249,10 +256,10 @@ void XMLCodeGenerator::writeCodeLink(CodeSymbolType,
   XML_DB(("(writeCodeLink)\n"));
   if (m_insideCodeLine && !m_insideSpecialHL && m_normalHLNeedStartTag)
   {
-    m_t << "<highlight class=\"normal\">";
+    *m_t << "<highlight class=\"normal\">";
     m_normalHLNeedStartTag=FALSE;
   }
-  writeXMLLink(m_t,ref,file,anchor,name,tooltip);
+  writeXMLLink(*m_t,ref,file,anchor,name,tooltip);
   m_col+=name.length();
 }
 void XMLCodeGenerator::writeTooltip(const QCString &, const DocLinkInfo &, const QCString &,
@@ -264,28 +271,28 @@ void XMLCodeGenerator::writeTooltip(const QCString &, const DocLinkInfo &, const
 void XMLCodeGenerator::startCodeLine(bool)
 {
   XML_DB(("(startCodeLine)\n"));
-  m_t << "<codeline";
+  *m_t << "<codeline";
   if (m_lineNumber!=-1)
   {
-    m_t << " lineno=\"" << m_lineNumber << "\"";
+    *m_t << " lineno=\"" << m_lineNumber << "\"";
     if (!m_refId.isEmpty())
     {
-      m_t << " refid=\"" << m_refId << "\"";
+      *m_t << " refid=\"" << m_refId << "\"";
       if (m_isMemberRef)
       {
-        m_t << " refkind=\"member\"";
+        *m_t << " refkind=\"member\"";
       }
       else
       {
-        m_t << " refkind=\"compound\"";
+        *m_t << " refkind=\"compound\"";
       }
     }
     if (!m_external.isEmpty())
     {
-      m_t << " external=\"" << m_external << "\"";
+      *m_t << " external=\"" << m_external << "\"";
     }
   }
-  m_t << ">";
+  *m_t << ">";
   m_insideCodeLine=TRUE;
   m_col=0;
 }
@@ -294,10 +301,10 @@ void XMLCodeGenerator::endCodeLine()
   XML_DB(("(endCodeLine)\n"));
   if (!m_insideSpecialHL && !m_normalHLNeedStartTag)
   {
-    m_t << "</highlight>";
+    *m_t << "</highlight>";
     m_normalHLNeedStartTag=TRUE;
   }
-  m_t << "</codeline>\n"; // non DocBook
+  *m_t << "</codeline>\n"; // non DocBook
   m_lineNumber = -1;
   m_refId.resize(0);
   m_external.resize(0);
@@ -308,16 +315,16 @@ void XMLCodeGenerator::startFontClass(const QCString &colorClass)
   XML_DB(("(startFontClass)\n"));
   if (m_insideCodeLine && !m_insideSpecialHL && !m_normalHLNeedStartTag)
   {
-    m_t << "</highlight>";
+    *m_t << "</highlight>";
     m_normalHLNeedStartTag=TRUE;
   }
-  m_t << "<highlight class=\"" << colorClass << "\">"; // non DocBook
+  *m_t << "<highlight class=\"" << colorClass << "\">"; // non DocBook
   m_insideSpecialHL=TRUE;
 }
 void XMLCodeGenerator::endFontClass()
 {
   XML_DB(("(endFontClass)\n"));
-  m_t << "</highlight>"; // non DocBook
+  *m_t << "</highlight>"; // non DocBook
   m_insideSpecialHL=FALSE;
 }
 void XMLCodeGenerator::writeCodeAnchor(const QCString &)
@@ -325,7 +332,7 @@ void XMLCodeGenerator::writeCodeAnchor(const QCString &)
   XML_DB(("(writeCodeAnchor)\n"));
 }
 void XMLCodeGenerator::writeLineNumber(const QCString &extRef,const QCString &compId,
-                     const QCString &anchorId,int l)
+                     const QCString &anchorId,int l,bool)
 {
   XML_DB(("(writeLineNumber)\n"));
   // we remember the information provided here to use it
@@ -334,7 +341,7 @@ void XMLCodeGenerator::writeLineNumber(const QCString &extRef,const QCString &co
   if (!compId.isEmpty())
   {
     m_refId=compId;
-    if (!anchorId.isEmpty()) m_refId+=(QCString)"_1"+anchorId;
+    if (!anchorId.isEmpty()) m_refId+=QCString("_1")+anchorId;
     m_isMemberRef = anchorId!=0;
     if (!extRef.isEmpty()) m_external=extRef;
   }
@@ -346,12 +353,12 @@ void XMLCodeGenerator::finish()
 
 void XMLCodeGenerator::startCodeFragment(const QCString &)
 {
-  m_t << "    <programlisting>\n";
+  *m_t << "    <programlisting>\n";
 }
 
 void XMLCodeGenerator::endCodeFragment(const QCString &)
 {
-  m_t << "    </programlisting>\n";
+  *m_t << "    </programlisting>\n";
 }
 
 //-------------------------------------------------------------------------------------------
@@ -424,17 +431,22 @@ static void writeXMLDocBlock(TextStream &t,
   QCString stext = text.stripWhiteSpace();
   if (stext.isEmpty()) return;
   // convert the documentation string into an abstract syntax tree
-  std::unique_ptr<IDocParser> parser { createDocParser() };
-  std::unique_ptr<DocNode>    root   { validatingParseDoc(*parser.get(),
-                                       fileName,lineNr,scope,md,text,FALSE,FALSE,
-                                       QCString(),FALSE,FALSE,Config_getBool(MARKDOWN_SUPPORT)) };
-  // create a code generator
-  auto xmlCodeGen = std::make_unique<XMLCodeGenerator>(t);
-  // create a parse tree visitor for XML
-  auto visitor = std::make_unique<XmlDocVisitor>(t,*xmlCodeGen,scope?scope->getDefFileExtension():QCString(""));
-  // visit all nodes
-  root->accept(visitor.get());
-  // clean up
+  auto parser { createDocParser() };
+  auto ast    { validatingParseDoc(*parser.get(),
+                                   fileName,lineNr,scope,md,text,FALSE,FALSE,
+                                   QCString(),FALSE,FALSE,Config_getBool(MARKDOWN_SUPPORT)) };
+  auto astImpl = dynamic_cast<const DocNodeAST*>(ast.get());
+  if (astImpl)
+  {
+    // create a code generator
+    OutputCodeList xmlCodeList;
+    xmlCodeList.add<XMLCodeGenerator>(&t);
+    // create a parse tree visitor for XML
+    XmlDocVisitor visitor(t,xmlCodeList,scope?scope->getDefFileExtension():QCString(""));
+    // visit all nodes
+    std::visit(visitor,astImpl->root);
+    // clean up
+  }
 }
 
 void writeXMLCodeBlock(TextStream &t,FileDef *fd)
@@ -442,14 +454,15 @@ void writeXMLCodeBlock(TextStream &t,FileDef *fd)
   auto intf=Doxygen::parserManager->getCodeParser(fd->getDefFileExtension());
   SrcLangExt langExt = getLanguageFromFileName(fd->getDefFileExtension());
   intf->resetCodeParserState();
-  XMLCodeGenerator *xmlGen = new XMLCodeGenerator(t);
-  xmlGen->startCodeFragment("DoxyCode");
-  intf->parseCode(*xmlGen,    // codeOutIntf
-                QCString(),           // scopeName
+  OutputCodeList xmlList;
+  xmlList.add<XMLCodeGenerator>(&t);
+  xmlList.startCodeFragment("DoxyCode");
+  intf->parseCode(xmlList,    // codeOutList
+                QCString(),   // scopeName
                 fileToString(fd->absFilePath(),Config_getBool(FILTER_SOURCE_FILES)),
                 langExt,     // lang
                 FALSE,       // isExampleBlock
-                QCString(),           // exampleName
+                QCString(),  // exampleName
                 fd,          // fileDef
                 -1,          // startLine
                 -1,          // endLine
@@ -457,9 +470,8 @@ void writeXMLCodeBlock(TextStream &t,FileDef *fd)
                 0,           // memberDef
                 TRUE         // showLineNumbers
                 );
-  xmlGen->endCodeFragment("DoxyCode");
-  xmlGen->finish();
-  delete xmlGen;
+  xmlList.endCodeFragment("DoxyCode");
+  xmlList.get<XMLCodeGenerator>()->finish();
 }
 
 static void writeMemberReference(TextStream &t,const Definition *def,const MemberDef *rmd,const QCString &tagName)
@@ -485,9 +497,36 @@ static void writeMemberReference(TextStream &t,const Definition *def,const Membe
 
 }
 
+// removes anonymous markers like '@1' from s.
+// examples '@3::A' -> '::A', 'A::@2::B' -> 'A::B', '@A' -> '@A'
+static void stripAnonymousMarkers(QCString &s)
+{
+  auto isDigit = [](char c) { return c>='0' && c<='9'; };
+  int len = static_cast<int>(s.length());
+  int i=0,j=0;
+  if (len>0)
+  {
+    while (i<len)
+    {
+      if (i<len-1 && s[i]=='@' && isDigit(s[i+1])) // found pattern '@\d+'
+      {
+        if (j>=2 && i>=2 && s[i-2]==':' && s[i-1]==':') j-=2; // found pattern '::@\d+'
+        i+=2;                               // skip over @ and first digit
+        while (i<len && isDigit(s[i])) i++; // skip additional digits
+      }
+      else // copy characters
+      {
+        s[j++]=s[i++];
+      }
+    }
+    // resize resulting string
+    s.resize(j+1);
+  }
+}
+
 static void stripQualifiers(QCString &typeStr)
 {
-  bool done=FALSE;
+  bool done=false;
   typeStr.stripPrefix("friend ");
   while (!done)
   {
@@ -500,7 +539,7 @@ static void stripQualifiers(QCString &typeStr)
 
 static QCString classOutputFileBase(const ClassDef *cd)
 {
-  //static bool inlineGroupedClasses = Config_getBool(INLINE_GROUPED_CLASSES);
+  //bool inlineGroupedClasses = Config_getBool(INLINE_GROUPED_CLASSES);
   //if (inlineGroupedClasses && cd->partOfGroups()!=0)
   return cd->getOutputFileBase();
   //else
@@ -509,7 +548,7 @@ static QCString classOutputFileBase(const ClassDef *cd)
 
 static QCString memberOutputFileBase(const MemberDef *md)
 {
-  //static bool inlineGroupedClasses = Config_getBool(INLINE_GROUPED_CLASSES);
+  //bool inlineGroupedClasses = Config_getBool(INLINE_GROUPED_CLASSES);
   //if (inlineGroupedClasses && md->getClassDef() && md->getClassDef()->partOfGroups()!=0)
   //  return md->getClassDef()->getXmlOutputFileBase();
   //else
@@ -540,7 +579,7 @@ static void generateXMLForMember(const MemberDef *md,TextStream &ti,TextStream &
   if (md->isHidden()) return;
 
   // group members are only visible in their group
-  //if (def->definitionType()!=Definition::TypeGroup && md->getGroupDef()) return;
+  bool groupMember = md->getGroupDef() && def->definitionType()!=Definition::TypeGroup;
 
   QCString memType;
   bool isFunc=FALSE;
@@ -564,36 +603,37 @@ static void generateXMLForMember(const MemberDef *md,TextStream &ti,TextStream &
     case MemberType_Dictionary:  memType="dictionary";  break;
   }
 
+  QCString nameStr = md->name();
+  stripAnonymousMarkers(nameStr);
   ti << "    <member refid=\"" << memberOutputFileBase(md)
      << "_1" << md->anchor() << "\" kind=\"" << memType << "\"><name>"
-     << convertToXML(md->name()) << "</name></member>\n";
+     << convertToXML(nameStr) << "</name></member>\n";
 
-  QCString scopeName;
-  if (md->getClassDef())
-    scopeName=md->getClassDef()->name();
-  else if (md->getNamespaceDef())
-    scopeName=md->getNamespaceDef()->name();
-
-  t << "      <memberdef kind=\"";
-  //enum { define_t,variable_t,typedef_t,enum_t,function_t } xmlType = function_t;
-  t << memType << "\" id=\"";
-  if (md->getGroupDef() && def->definitionType()==Definition::TypeGroup)
+  if (groupMember)
   {
-    t << md->getGroupDef()->getOutputFileBase();
+    t << "      <member refid=\""
+      << md->getGroupDef()->getOutputFileBase()
+      << "_1" << md->anchor() << "\" kind=\"" << memType << "\"><name>"
+      << convertToXML(nameStr) << "</name></member>\n";
+    return;
   }
   else
   {
+    t << "      <memberdef kind=\"";
+    t << memType << "\" id=\"";
     t << memberOutputFileBase(md);
+    t << "_1"      // encoded ':' character (see util.cpp:convertNameToFile)
+      << md->anchor();
   }
-  t << "_1"      // encoded ':' character (see util.cpp:convertNameToFile)
-    << md->anchor();
+  //enum { define_t,variable_t,typedef_t,enum_t,function_t } xmlType = function_t;
+
   t << "\" prot=\"";
-  switch(md->protection())
+  switch (md->protection())
   {
-    case Public:    t << "public";     break;
-    case Protected: t << "protected";  break;
-    case Private:   t << "private";    break;
-    case Package:   t << "package";    break;
+    case Protection::Public:    t << "public";     break;
+    case Protection::Protected: t << "protected";  break;
+    case Protection::Private:   t << "private";    break;
+    case Protection::Package:   t << "package";    break;
   }
   t << "\"";
 
@@ -666,9 +706,9 @@ static void generateXMLForMember(const MemberDef *md,TextStream &ti,TextStream &
     t << " virt=\"";
     switch (md->virtualness())
     {
-      case Normal:  t << "non-virtual";  break;
-      case Virtual: t << "virtual";      break;
-      case Pure:    t << "pure-virtual"; break;
+      case Specifier::Normal:  t << "non-virtual";  break;
+      case Specifier::Virtual: t << "virtual";      break;
+      case Specifier::Pure:    t << "pure-virtual"; break;
       default: ASSERT(0);
     }
     t << "\"";
@@ -804,11 +844,14 @@ static void generateXMLForMember(const MemberDef *md,TextStream &ti,TextStream &
   {
     writeMemberTemplateLists(md,t);
     QCString typeStr = md->typeString();
+    stripAnonymousMarkers(typeStr);
     stripQualifiers(typeStr);
     t << "        <type>";
     linkifyText(TextGeneratorXMLImpl(t),def,md->getBodyDef(),md,typeStr);
     t << "</type>\n";
-    t << "        <definition>" << convertToXML(md->definition()) << "</definition>\n";
+    QCString defStr = md->definition();
+    stripAnonymousMarkers(defStr);
+    t << "        <definition>" << convertToXML(defStr) << "</definition>\n";
     t << "        <argsstring>" << convertToXML(md->argsString()) << "</argsstring>\n";
   }
 
@@ -819,7 +862,13 @@ static void generateXMLForMember(const MemberDef *md,TextStream &ti,TextStream &
     t << "</type>\n";
   }
 
-  t << "        <name>" << convertToXML(md->name()) << "</name>\n";
+  QCString qualifiedNameStr = md->qualifiedName();;
+  stripAnonymousMarkers(qualifiedNameStr);
+  t << "        <name>" << convertToXML(nameStr) << "</name>\n";
+  if (nameStr!=qualifiedNameStr)
+  {
+    t << "        <qualifiedname>" << convertToXML(qualifiedNameStr) << "</qualifiedname>\n";
+  }
 
   if (md->memberType() == MemberType_Property)
   {
@@ -850,11 +899,16 @@ static void generateXMLForMember(const MemberDef *md,TextStream &ti,TextStream &
       << convertToXML(rbmd->name()) << "</reimplementedby>\n";
   }
 
+  for (const auto &qmd : md->getQualifiers())
+  {
+    t << "        <qualifier>" << convertToXML(qmd.c_str()) << "</qualifier>\n";
+  }
+
   if (md->isFriendClass()) // for friend classes we show a link to the class as a "parameter"
   {
     t << "        <param>\n";
     t << "          <type>";
-    linkifyText(TextGeneratorXMLImpl(t),def,md->getBodyDef(),md,md->name());
+    linkifyText(TextGeneratorXMLImpl(t),def,md->getBodyDef(),md,nameStr);
     t << "</type>\n";
     t << "        </param>\n";
   }
@@ -862,6 +916,7 @@ static void generateXMLForMember(const MemberDef *md,TextStream &ti,TextStream &
   {
     const ArgumentList &declAl = md->declArgumentList();
     const ArgumentList &defAl = md->argumentList();
+    bool isFortran = md->getLanguage()==SrcLangExt_Fortran;
     if (declAl.hasParameters())
     {
       auto defIt = defAl.begin();
@@ -881,7 +936,13 @@ static void generateXMLForMember(const MemberDef *md,TextStream &ti,TextStream &
           writeXMLString(t,a.attrib);
           t << "</attributes>\n";
         }
-        if (!a.type.isEmpty())
+        if (isFortran && defArg && !defArg->type.isEmpty())
+        {
+          t << "          <type>";
+          linkifyText(TextGeneratorXMLImpl(t),def,md->getBodyDef(),md,defArg->type);
+          t << "</type>\n";
+        }
+        else if (!a.type.isEmpty())
         {
           t << "          <type>";
           linkifyText(TextGeneratorXMLImpl(t),def,md->getBodyDef(),md,a.type);
@@ -971,10 +1032,10 @@ static void generateXMLForMember(const MemberDef *md,TextStream &ti,TextStream &
         << emd->anchor() << "\" prot=\"";
       switch (emd->protection())
       {
-        case Public:    t << "public";    break;
-        case Protected: t << "protected"; break;
-        case Private:   t << "private";   break;
-        case Package:   t << "package";   break;
+        case Protection::Public:    t << "public";    break;
+        case Protection::Protected: t << "protected"; break;
+        case Protection::Private:   t << "private";   break;
+        case Protection::Package:   t << "package";   break;
       }
       t << "\">\n";
       t << "          <name>";
@@ -1106,17 +1167,17 @@ static void writeListOfAllMembers(const ClassDef *cd,TextStream &t)
           md->anchor() << "\" prot=\"";
         switch (prot)
         {
-          case Public:    t << "public";    break;
-          case Protected: t << "protected"; break;
-          case Private:   t << "private";   break;
-          case Package:   t << "package";   break;
+          case Protection::Public:    t << "public";    break;
+          case Protection::Protected: t << "protected"; break;
+          case Protection::Private:   t << "private";   break;
+          case Protection::Package:   t << "package";   break;
         }
         t << "\" virt=\"";
         switch(virt)
         {
-          case Normal:  t << "non-virtual";  break;
-          case Virtual: t << "virtual";      break;
-          case Pure:    t << "pure-virtual"; break;
+          case Specifier::Normal:  t << "non-virtual";  break;
+          case Specifier::Virtual: t << "virtual";      break;
+          case Specifier::Pure:    t << "pure-virtual"; break;
         }
         t << "\"";
         if (!mi->ambiguityResolutionScope().isEmpty())
@@ -1141,16 +1202,25 @@ static void writeInnerClasses(const ClassLinkedRefMap &cl,TextStream &t)
         << "\" prot=\"";
       switch(cd->protection())
       {
-         case Public:    t << "public";     break;
-         case Protected: t << "protected";  break;
-         case Private:   t << "private";    break;
-         case Package:   t << "package";    break;
+        case Protection::Public:    t << "public";     break;
+        case Protection::Protected: t << "protected";  break;
+        case Protection::Private:   t << "private";    break;
+        case Protection::Package:   t << "package";    break;
       }
       t << "\">" << convertToXML(cd->name()) << "</innerclass>\n";
     }
   }
 }
 
+static void writeInnerConcepts(const ConceptLinkedRefMap &cl,TextStream &t)
+{
+  for (const auto &cd : cl)
+  {
+    t << "    <innerconcept refid=\"" << cd->getOutputFileBase()
+      << "\">" << convertToXML(cd->name()) << "</innerconcept>\n";
+  }
+}
+
 static void writeInnerNamespaces(const NamespaceLinkedRefMap &nl,TextStream &t)
 {
   for (const auto &nd : nl)
@@ -1260,7 +1330,7 @@ static void generateXMLForClass(const ClassDef *cd,TextStream &ti)
 
   QCString outputDirectory = Config_getString(XML_OUTPUT);
   QCString fileName=outputDirectory+"/"+ classOutputFileBase(cd)+".xml";
-  std::ofstream f(fileName.str(),std::ofstream::out | std::ofstream::binary);
+  std::ofstream f = Portable::openOutputStream(fileName);
   if (!f.is_open())
   {
     err("Cannot open file %s for writing!\n",qPrint(fileName));
@@ -1275,17 +1345,19 @@ static void generateXMLForClass(const ClassDef *cd,TextStream &ti)
     << langToString(cd->getLanguage()) << "\" prot=\"";
   switch (cd->protection())
   {
-    case Public:    t << "public";    break;
-    case Protected: t << "protected"; break;
-    case Private:   t << "private";   break;
-    case Package:   t << "package";   break;
+    case Protection::Public:    t << "public";    break;
+    case Protection::Protected: t << "protected"; break;
+    case Protection::Private:   t << "private";   break;
+    case Protection::Package:   t << "package";   break;
   }
   if (cd->isFinal()) t << "\" final=\"yes";
   if (cd->isSealed()) t << "\" sealed=\"yes";
   if (cd->isAbstract()) t << "\" abstract=\"yes";
   t << "\">\n";
   t << "    <compoundname>";
-  writeXMLString(t,cd->name());
+  QCString nameStr = cd->name();
+  stripAnonymousMarkers(nameStr);
+  writeXMLString(t,nameStr);
   t << "</compoundname>\n";
   for (const auto &bcd : cd->baseClasses())
   {
@@ -1297,17 +1369,17 @@ static void generateXMLForClass(const ClassDef *cd,TextStream &ti)
     t << "prot=\"";
     switch (bcd.prot)
     {
-      case Public:    t << "public";    break;
-      case Protected: t << "protected"; break;
-      case Private:   t << "private";   break;
-      case Package: ASSERT(0); break;
+      case Protection::Public:    t << "public";    break;
+      case Protection::Protected: t << "protected"; break;
+      case Protection::Private:   t << "private";   break;
+      case Protection::Package: ASSERT(0); break;
     }
     t << "\" virt=\"";
     switch(bcd.virt)
     {
-      case Normal:  t << "non-virtual";  break;
-      case Virtual: t << "virtual";      break;
-      case Pure:    t <<"pure-virtual"; break;
+      case Specifier::Normal:  t << "non-virtual";  break;
+      case Specifier::Virtual: t << "virtual";      break;
+      case Specifier::Pure:    t <<"pure-virtual"; break;
     }
     t << "\">";
     if (!bcd.templSpecifiers.isEmpty())
@@ -1330,17 +1402,17 @@ static void generateXMLForClass(const ClassDef *cd,TextStream &ti)
       << "\" prot=\"";
     switch (bcd.prot)
     {
-      case Public:    t << "public";    break;
-      case Protected: t << "protected"; break;
-      case Private:   t << "private";   break;
-      case Package: ASSERT(0); break;
+      case Protection::Public:    t << "public";    break;
+      case Protection::Protected: t << "protected"; break;
+      case Protection::Private:   t << "private";   break;
+      case Protection::Package: ASSERT(0); break;
     }
     t << "\" virt=\"";
     switch (bcd.virt)
     {
-      case Normal:  t << "non-virtual";  break;
-      case Virtual: t << "virtual";      break;
-      case Pure:    t << "pure-virtual"; break;
+      case Specifier::Normal:  t << "non-virtual";  break;
+      case Specifier::Virtual: t << "virtual";      break;
+      case Specifier::Pure:    t << "pure-virtual"; break;
     }
     t << "\">" << convertToXML(bcd.classDef->displayName())
       << "</derivedcompoundref>\n";
@@ -1372,6 +1444,11 @@ static void generateXMLForClass(const ClassDef *cd,TextStream &ti)
     t << "    </requiresclause>\n";
   }
 
+  for (const auto &qcd : cd->getQualifiers())
+  {
+    t << "    <qualifier>" << convertToXML(qcd.c_str()) << "</qualifier>\n";
+  }
+
   t << "    <briefdescription>\n";
   writeXMLDocBlock(t,cd->briefFile(),cd->briefLine(),cd,0,cd->briefDescription());
   t << "    </briefdescription>\n";
@@ -1424,7 +1501,7 @@ static void generateXMLForConcept(const ConceptDef *cd,TextStream &ti)
 
   QCString outputDirectory = Config_getString(XML_OUTPUT);
   QCString fileName=outputDirectory+"/"+cd->getOutputFileBase()+".xml";
-  std::ofstream f(fileName.str(),std::ofstream::out | std::ofstream::binary);
+  std::ofstream f = Portable::openOutputStream(fileName);
   if (!f.is_open())
   {
     err("Cannot open file %s for writing!\n",qPrint(fileName));
@@ -1435,7 +1512,9 @@ static void generateXMLForConcept(const ConceptDef *cd,TextStream &ti)
   t << "  <compounddef id=\"" << cd->getOutputFileBase()
     << "\" kind=\"concept\">\n";
   t << "    <compoundname>";
-  writeXMLString(t,cd->name());
+  QCString nameStr = cd->name();
+  stripAnonymousMarkers(nameStr);
+  writeXMLString(t,nameStr);
   t << "</compoundname>\n";
   writeIncludeInfo(cd->includeInfo(),t);
   writeTemplateList(cd,t);
@@ -1477,7 +1556,7 @@ static void generateXMLForNamespace(const NamespaceDef *nd,TextStream &ti)
 
   QCString outputDirectory = Config_getString(XML_OUTPUT);
   QCString fileName=outputDirectory+"/"+nd->getOutputFileBase()+".xml";
-  std::ofstream f(fileName.str(),std::ofstream::out | std::ofstream::binary);
+  std::ofstream f = Portable::openOutputStream(fileName);
   if (!f.is_open())
   {
     err("Cannot open file %s for writing!\n",qPrint(fileName));
@@ -1492,10 +1571,13 @@ static void generateXMLForNamespace(const NamespaceDef *nd,TextStream &ti)
     << "language=\""
     << langToString(nd->getLanguage()) << "\">\n";
   t << "    <compoundname>";
-  writeXMLString(t,nd->name());
+  QCString nameStr = nd->name();
+  stripAnonymousMarkers(nameStr);
+  writeXMLString(t,nameStr);
   t << "</compoundname>\n";
 
   writeInnerClasses(nd->getClasses(),t);
+  writeInnerConcepts(nd->getConcepts(),t);
   writeInnerNamespaces(nd->getNamespaces(),t);
 
   for (const auto &mg : nd->getMemberGroups())
@@ -1552,7 +1634,7 @@ static void generateXMLForFile(FileDef *fd,TextStream &ti)
 
   QCString outputDirectory = Config_getString(XML_OUTPUT);
   QCString fileName=outputDirectory+"/"+fd->getOutputFileBase()+".xml";
-  std::ofstream f(fileName.str(),std::ofstream::out | std::ofstream::binary);
+  std::ofstream f = Portable::openOutputStream(fileName);
   if (!f.is_open())
   {
     err("Cannot open file %s for writing!\n",qPrint(fileName));
@@ -1609,6 +1691,7 @@ static void generateXMLForFile(FileDef *fd,TextStream &ti)
   }
 
   writeInnerClasses(fd->getClasses(),t);
+  writeInnerConcepts(fd->getConcepts(),t);
   writeInnerNamespaces(fd->getNamespaces(),t);
 
   for (const auto &mg : fd->getMemberGroups())
@@ -1663,7 +1746,7 @@ static void generateXMLForGroup(const GroupDef *gd,TextStream &ti)
 
   QCString outputDirectory = Config_getString(XML_OUTPUT);
   QCString fileName=outputDirectory+"/"+gd->getOutputFileBase()+".xml";
-  std::ofstream f(fileName.str(),std::ofstream::out | std::ofstream::binary);
+  std::ofstream f = Portable::openOutputStream(fileName);
   if (!f.is_open())
   {
     err("Cannot open file %s for writing!\n",qPrint(fileName));
@@ -1679,6 +1762,7 @@ static void generateXMLForGroup(const GroupDef *gd,TextStream &ti)
 
   writeInnerFiles(gd->getFiles(),t);
   writeInnerClasses(gd->getClasses(),t);
+  writeInnerConcepts(gd->getConcepts(),t);
   writeInnerNamespaces(gd->getNamespaces(),t);
   writeInnerPages(gd->getPages(),t);
   writeInnerGroups(gd->getSubGroups(),t);
@@ -1718,7 +1802,7 @@ static void generateXMLForDir(DirDef *dd,TextStream &ti)
 
   QCString outputDirectory = Config_getString(XML_OUTPUT);
   QCString fileName=outputDirectory+"/"+dd->getOutputFileBase()+".xml";
-  std::ofstream f(fileName.str(),std::ofstream::out | std::ofstream::binary);
+  std::ofstream f = Portable::openOutputStream(fileName);
   if (!f.is_open())
   {
     err("Cannot open file %s for writing!\n",qPrint(fileName));
@@ -1761,7 +1845,7 @@ static void generateXMLForPage(PageDef *pd,TextStream &ti,bool isExample)
   QCString pageName = pd->getOutputFileBase();
   if (pd->getGroupDef())
   {
-    pageName+=(QCString)"_"+pd->name();
+    pageName+=QCString("_")+pd->name();
   }
   if (pageName=="index") pageName="indexpage"; // to prevent overwriting the generated index page.
 
@@ -1771,7 +1855,7 @@ static void generateXMLForPage(PageDef *pd,TextStream &ti,bool isExample)
 
   QCString outputDirectory = Config_getString(XML_OUTPUT);
   QCString fileName=outputDirectory+"/"+pageName+".xml";
-  std::ofstream f(fileName.str(),std::ofstream::out | std::ofstream::binary);
+  std::ofstream f = Portable::openOutputStream(fileName);
   if (!f.is_open())
   {
     err("Cannot open file %s for writing!\n",qPrint(fileName));
@@ -1790,7 +1874,7 @@ static void generateXMLForPage(PageDef *pd,TextStream &ti,bool isExample)
     QCString title;
     if (mainPageHasTitle())
     {
-      title = filterTitle(convertCharEntitiesToUTF8(Doxygen::mainPage->title()).str());
+      title = filterTitle(convertCharEntitiesToUTF8(Doxygen::mainPage->title()));
     }
     else
     {
@@ -1804,7 +1888,7 @@ static void generateXMLForPage(PageDef *pd,TextStream &ti,bool isExample)
     const SectionInfo *si = SectionManager::instance().find(pd->name());
     if (si)
     {
-      t << "    <title>" << convertToXML(filterTitle(convertCharEntitiesToUTF8(si->title()).str()))
+      t << "    <title>" << convertToXML(filterTitle(convertCharEntitiesToUTF8(si->title())))
         << "</title>\n";
     }
   }
@@ -1821,7 +1905,7 @@ static void generateXMLForPage(PageDef *pd,TextStream &ti,bool isExample)
       if (isSection(si->type()))
       {
         //printf("  level=%d title=%s\n",level,qPrint(si->title));
-        int nextLevel = (int)si->type();
+        int nextLevel = static_cast<int>(si->type());
         if (nextLevel>level)
         {
           for (l=level;l<nextLevel;l++)
@@ -1842,9 +1926,11 @@ static void generateXMLForPage(PageDef *pd,TextStream &ti,bool isExample)
         {
           if (inLi[nextLevel]) t << "    </tocsect>\n";
           QCString titleDoc = convertToXML(si->title());
+          QCString label = convertToXML(si->label());
+          if (titleDoc.isEmpty()) titleDoc = label;
           t << "      <tocsect>\n";
-          t << "        <name>" << (si->title().isEmpty()?si->label():titleDoc) << "</name>\n";
-          t << "        <reference>"  <<  convertToXML(pageName) << "_1" << convertToXML(si->label()) << "</reference>\n";
+          t << "        <name>" << titleDoc << "</name>\n";
+          t << "        <reference>"  <<  convertToXML(pageName) << "_1" << label << "</reference>\n";
           inLi[nextLevel]=TRUE;
           level = nextLevel;
         }
@@ -1904,7 +1990,7 @@ void generateXML()
   ResourceMgr::instance().copyResource("doxyfile.xsd",outputDirectory);
 
   QCString fileName=outputDirectory+"/compound.xsd";
-  std::ofstream f(fileName.str(),std::ofstream::out | std::ofstream::binary);
+  std::ofstream f = Portable::openOutputStream(fileName);
   if (!f.is_open())
   {
     err("Cannot open file %s for writing!\n",qPrint(fileName));
@@ -1927,7 +2013,7 @@ void generateXML()
         QCString s(startLine,len);
         if (s.find("<!-- Automatically insert here the HTML entities -->")!=-1)
         {
-          HtmlEntityMapper::instance()->writeXMLSchema(t);
+          HtmlEntityMapper::instance().writeXMLSchema(t);
         }
         else
         {
@@ -1940,7 +2026,7 @@ void generateXML()
   f.close();
 
   fileName=outputDirectory+"/Doxyfile.xml";
-  f.open(fileName.str(),std::ofstream::out | std::ofstream::binary);
+  f = Portable::openOutputStream(fileName);
   if (!f.is_open())
   {
     err("Cannot open file %s for writing\n",fileName.data());
@@ -1954,7 +2040,7 @@ void generateXML()
   f.close();
 
   fileName=outputDirectory+"/index.xml";
-  f.open(fileName.str(),std::ofstream::out | std::ofstream::binary);
+  f = Portable::openOutputStream(fileName);
   if (!f.is_open())
   {
     err("Cannot open file %s for writing!\n",qPrint(fileName));
